@@ -1,11 +1,8 @@
-# coding=utf-8
-
-from __future__ import unicode_literals
 from .. import Provider as AddressProvider
 
 
 class Provider(AddressProvider):
-    building_number_formats = ('#', '##', '###', '#', '##', '###',)
+    building_number_formats = ('#', '##', '###', '#', '##', '###')
 
     street_suffixes = (
         'baan', 'boulevard', 'dreef', 'hof', 'laan', 'pad',
@@ -14,7 +11,7 @@ class Provider(AddressProvider):
 
     # the 4 digit numerical part of Dutch postcodes is between 1000 and 9999;
     # see http://nl.wikipedia.org/wiki/Postcode#Postcodes_in_Nederland
-    postcode_formats = ('%###??', '%### ??',)
+    postcode_formats = ('%###??', '%### ??')
 
     city_formats = ('{{city}}',)
 
@@ -583,8 +580,10 @@ class Provider(AddressProvider):
         "{{street_address}}\n{{postcode}}\n{{city}}",
     )
 
-    def province(self):
+    def administrative_unit(self):
         return self.random_element(self.provinces)
 
+    province = administrative_unit
+
     def city(self):
         return self.random_element(self.cities)
