@@ -2,8 +2,13 @@ from .. import Provider as AutomotiveProvider
 
 
 class Provider(AutomotiveProvider):
-    # from
-    # https://en.wikipedia.org/wiki/Vehicle_registration_plates_of_Poland
+    """Implement automotive provider for ``pl_PL`` locale.
+
+    Sources:
+
+    - https://en.wikipedia.org/wiki/Vehicle_registration_plates_of_Poland
+    """
+
     license_formats = (
         '?? #####',
         '?? ####?',
@@ -22,4 +27,11 @@ class Provider(AutomotiveProvider):
     )
 
     def license_plate_regex_formats(self):
+        """Return a regex for matching license plates.
+
+        .. warning::
+           This is technically not a method that generates fake data, and it
+           should not be part of the public API. User should refrain from using
+           this method.
+        """
         return [plate.replace('?', '[A-Z]').replace('#', '[0-9]') for plate in self.license_formats]
