@@ -1,5 +1,3 @@
-# coding=utf-8
-from __future__ import unicode_literals
 from .. import Provider as InternetProvider
 
 
@@ -13,3 +11,11 @@ class Provider(InternetProvider):
         'bol.com.br',
         'ig.com.br')
     tlds = ('com', 'com', 'com', 'net', 'org', 'br', 'br', 'br')
+    replacements = (
+        ('à', 'a'), ('â', 'a'), ('ã', 'a'),
+        ('ç', 'c'),
+        ('é', 'e'), ('ê', 'e'),
+        ('í', 'i'),
+        ('ô', 'o'), ('ö', 'o'), ('õ', 'o'),
+        ('ú', 'u'),
+    )
